//  Diffusion Client Library for iOS, tvOS and OS X / macOS
//
//  Copyright (c) 2017 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;
#import <Diffusion/PTDiffusionTimeSeriesEventMetadata.h>

@class PTDiffusionBytes;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief An event in a time series.

 Two instances are equal if and only if they have identical attributes.
 Typically two instances that have the same sequence number will be equal, but
 this may not be true if the event has changed on the server.

 @since 6.0
 */
@interface PTDiffusionTimeSeriesEvent : PTDiffusionTimeSeriesEventMetadata

/**
 If this is an edit event, returns the metadata of the original event that this
 event replaces; otherwise returns this event.
 
 The result is always the metadata of an original event, never that of an edit
 event.

 @since 6.0
 */
@property(nonatomic, readonly) PTDiffusionTimeSeriesEventMetadata* originalEvent;

/**
 If this is an edit event then `YES`, otherwise `NO` indicating that this is an
 original event.
 
 @since 6.0
 */
@property(nonatomic, readonly, getter=isEditEvent) BOOL editEvent;

/**
 Compares the receiver to the given time series event.

 @param timeSeriesEvent The time series event object with which to compare the
 receiver.

 @return `YES` if it is identical to the receiver, otherwise `NO`.

 @since 6.0
 */
-(BOOL)isEqualToTimeSeriesEvent:(nullable PTDiffusionTimeSeriesEvent *)timeSeriesEvent;

@end

NS_ASSUME_NONNULL_END
